[gjs: 5/10] CI: Increase async test timeout under Valgrind




commit 050e44c68d1f71b68feb0a6ff8716eb5a48197a2
Author: Philip Chimento <philip chimento gmail com>
Date:   Fri Mar 12 15:50:02 2021 -0800

    CI: Increase async test timeout under Valgrind
    
    Just as we do for the GC modes, in a few cases the timeout for an async
    test needs to be increased when running under Valgrind.

 installed-tests/js/minijasmine.js | 9 +++++----
 1 file changed, 5 insertions(+), 4 deletions(-)
---
diff --git a/installed-tests/js/minijasmine.js b/installed-tests/js/minijasmine.js
index d783fa1d..a82251a4 100644
--- a/installed-tests/js/minijasmine.js
+++ b/installed-tests/js/minijasmine.js
@@ -115,9 +115,10 @@ class TapReporter {
 
 globalThis._jasmineEnv.addReporter(new TapReporter());
 
 // If we're running the tests in certain JS_GC_ZEAL modes, then some will time
 // out if the CI machine is under a certain load. In that case increase the
 // default timeout.
 const gcZeal = GLib.getenv('JS_GC_ZEAL');
-if (gcZeal && (gcZeal === '2' || gcZeal.startsWith('2,') || gcZeal === '4'))
+const valgrind = GLib.getenv('VALGRIND');
+if (valgrind || (gcZeal && (gcZeal === '2' || gcZeal.startsWith('2,') || gcZeal === '4')))
     jasmine.DEFAULT_TIMEOUT_INTERVAL *= 5;
@@ -115,9 +115,10 @@ class TapReporter {
 globalThis._jasmineEnv.addReporter(new TapReporter());
 
-// If we're running the tests in certain JS_GC_ZEAL modes, then some will time
-// out if the CI machine is under a certain load. In that case increase the
-// default timeout.
+// If we're running the tests in certain JS_GC_ZEAL modes or Valgrind, then some
+// will time out if the CI machine is under a certain load. In that case
+// increase the default timeout.
 const gcZeal = GLib.getenv('JS_GC_ZEAL');


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]